Method: Verifica::Ace#initialize

Defined in:
lib/verifica/ace.rb

#initialize(sid, action, allow) ⇒ Ace

Creates a new Access Control Entry with immutable state

Parameters:

  • sid (String)

    Security Identifier (SID), typically String, but could be any object with implemented equality methods and #hash

  • action (Symbol, String)

    action which is allowed or denied for given SID

  • allow (Boolean)

    allow or deny given action for given SID



32
33
34
35
36
37
# File 'lib/verifica/ace.rb', line 32

def initialize(sid, action, allow)
  @sid = sid.dup.freeze
  @action = action.to_sym
  @allow = allow
  freeze
end